Module response_types

Module response_types 

Response types for all war api endpoints.

For more detailed information on the contents of each response see the Foxhole War API definition.

Structs

MapDataResponse
Response for the /worldconquest/maps/{map}/dynamic|static endpoints.
MapItem
Contains information about a single item present on a map hex.
MapNameResponse
Response for the worldconquest/maps endpoint.
MapTextItem
Contains information about a map label.
WarDataResponse
Response for the worldconquest/war endpoint.
WarReportResponse
Response for the worldconquest/warReport/{map} endpoint.

Enums

IconType
The type of icon for a map item.
MapMarkerType
Indicates whether or not a map marker is major or minor.
TeamId
Team id for a map item.