pub struct WarReportResponse {
pub total_enlistments: u32,
pub colonial_casualties: u32,
pub warden_casualties: u32,
pub day_of_war: u32,
}Expand description
Response for the worldconquest/warReport/{map} endpoint.
This response contains information about the current state of the war for a given map.
Fields
total_enlistments: u32colonial_casualties: u32warden_casualties: u32day_of_war: u32Trait Implementations
Sourceimpl Clone for WarReportResponse
impl Clone for WarReportResponse
Sourcefn clone(&self) -> WarReportResponse
fn clone(&self) -> WarReportResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WarReportResponse
impl Debug for WarReportResponse
Sourceimpl<'de> Deserialize<'de> for WarReportResponse
impl<'de> Deserialize<'de> for WarReportResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WarReportResponse
Sourceimpl PartialEq for WarReportResponse
impl PartialEq for WarReportResponse
Sourcefn eq(&self, other: &WarReportResponse) -> bool
fn eq(&self, other: &WarReportResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for WarReportResponse