Response types for all war api endpoints.
For more detailed information on the contents of each response see the Foxhole War API definition.
Structs
- MapData
Response - Response for the /worldconquest/maps/{map}/dynamic|static endpoints.
- MapItem
- Contains information about a single item present on a map hex.
- MapName
Response - Response for the
worldconquest/mapsendpoint. - MapText
Item - Contains information about a map label.
- WarData
Response - Response for the
worldconquest/warendpoint. - WarReport
Response - Response for the
worldconquest/warReport/{map}endpoint.
Enums
- Icon
Type - The type of icon for a map item.
- MapMarker
Type - Indicates whether or not a map marker is major or minor.
- TeamId
- Team id for a map item.